summaryrefslogtreecommitdiffstats
path: root/kbackgammon/kbgboard.h
diff options
context:
space:
mode:
Diffstat (limited to 'kbackgammon/kbgboard.h')
-rw-r--r--kbackgammon/kbgboard.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kbackgammon/kbgboard.h b/kbackgammon/kbgboard.h
index c73c6fac..f91ab93b 100644
--- a/kbackgammon/kbgboard.h
+++ b/kbackgammon/kbgboard.h
@@ -110,7 +110,7 @@ class KBgBoard : public TQWidget
/**
* Constructor and destructor. Parameter as usual.
*/
- KBgBoard(TQWidget *tqparent = 0, const char *name = 0,
+ KBgBoard(TQWidget *parent = 0, const char *name = 0,
TQPopupMenu *menu = 0);
virtual ~KBgBoard();
@@ -469,7 +469,7 @@ class KBgBoardCell : public TQLabel
/**
* Constructor and destructor
*/
- KBgBoardCell(TQWidget * tqparent, int numID);
+ KBgBoardCell(TQWidget * parent, int numID);
virtual ~KBgBoardCell();
/**
@@ -560,7 +560,7 @@ protected:
/**
* the board and the pieces are one unit (none makes
* sense without the other). So the pieces know and access their tqparent.
*/
KBgBoard *board;
void checkAndMakeShortMove(TQMouseEvent *e, int m);
@@ -635,7 +635,7 @@ class KBgBoardHome : public KBgBoardCell
/**
* Constructor and destructor
*/
- KBgBoardHome( TQWidget * tqparent, int numID);
+ KBgBoardHome( TQWidget * parent, int numID);
virtual ~KBgBoardHome();
/**
@@ -698,7 +698,7 @@ class KBgBoardBar : public KBgBoardCell
/**
* Constructor
*/
- KBgBoardBar( TQWidget * tqparent, int numID );
+ KBgBoardBar( TQWidget * parent, int numID );
/**
* Destructor
@@ -734,7 +734,7 @@ class KBgBoardField : public KBgBoardCell
/**
* Constructor and destructor
*/
- KBgBoardField( TQWidget * tqparent, int numID);
+ KBgBoardField( TQWidget * parent, int numID);
virtual ~KBgBoardField();
/**
@@ -911,7 +911,7 @@ public:
/**
* Constructor
*/
- KBgBoardSetup(TQWidget *tqparent = 0, const char *name = 0,
+ KBgBoardSetup(TQWidget *parent = 0, const char *name = 0,
TQPopupMenu *menu = 0);
/**
@@ -560,7 +560,7 @@ protected:
/**
* the board and the pieces are one unit (none makes
- * sense without the other). So the pieces know and access their tqparent.
+ * sense without the other). So the pieces know and access their parent.
*/
KBgBoard *board;